#[non_exhaustive]pub enum ExchangeError {
#[non_exhaustive] Unquoted {
base: Currency,
quote: Currency,
},
#[non_exhaustive] Convert {
source: ConvertError,
},
}Expand description
An error from converting an amount against an Exchange.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
#[non_exhaustive]Unquoted
The table holds no rate for the pair.
Fields
This variant is marked as non-exhaustive
Non-exhaustive enum variants could have additional fields added in future. Therefore, non-exhaustive enum variants cannot be constructed in external crates and cannot be matched against.
#[non_exhaustive]Convert
The table quotes the pair, but converting at that rate failed. The source error says why, and names the pair.
Fields
This variant is marked as non-exhaustive
Non-exhaustive enum variants could have additional fields added in future. Therefore, non-exhaustive enum variants cannot be constructed in external crates and cannot be matched against.

source: ConvertErrorThe error ExchangeRate::convert gave.